@@ -8,17 +8,9 @@
 #ifndef KONSOLEPROFILES_H
 #define KONSOLEPROFILES_H
 
+#include "profilesmodel.h"
 #include <KRunner/AbstractRunner>
 
-class KDirWatch;
-
-struct KonsoleProfileData {
-    QString displayName;
-    QString iconName;
-};
-
-Q_DECLARE_TYPEINFO(KonsoleProfileData, Q_MOVABLE_TYPE);
-
 using namespace Plasma;
 
 class KonsoleProfiles : public AbstractRunner
@@ -27,19 +19,13 @@ class KonsoleProfiles : public AbstractRunner
 
 public:
     explicit KonsoleProfiles(QObject *parent, const KPluginMetaData &metaData, const QVariantList &args);
-    ~KonsoleProfiles() override;
 
-    void init() override;
     void match(RunnerContext &context) override;
     void run(const RunnerContext &context, const QueryMatch &match) override;
 
-private Q_SLOTS:
-    void loadProfiles();
-
 private:
-    KDirWatch *m_profileFilesWatch = nullptr;
-    QList<KonsoleProfileData> m_profiles;
-    QLatin1String m_triggerWord = QLatin1String("konsole");
+    ProfilesModel m_model;
+    const QLatin1String m_triggerWord = QLatin1String("konsole");
 };
 
 #endif
