@@ -20,15 +20,43 @@ using namespace std::chrono_literals;
 
 namespace
 {
-#if HAVE_NetworkManagerQt
 
+#if SUPPORT_METERED_DETECTION
 bool isUsingMeteredConnection()
 {
+#if QT_VERSION >= QT_VERSION_CHECK(6, 3, 0)
+    const auto instance = QNetworkInformation::instance();
+    if (instance->supports(QNetworkInformation::Feature::Metered)) {
+        return instance->isMetered();
+    } else if (instance->supports(QNetworkInformation::Feature::TransportMedium)) {
+        const auto transport = instance->transportMedium();
+        return transport == QNetworkInformation::TransportMedium::Cellular //
+            || transport == QNetworkInformation::TransportMedium::Bluetooth;
+    }
+    return false;
+#elif HAVE_NetworkManagerQt
     const auto metered = NetworkManager::metered();
     return metered == NetworkManager::Device::MeteredStatus::GuessYes //
         || metered == NetworkManager::Device::MeteredStatus::Yes;
-}
 #endif
+    Q_UNREACHABLE();
+}
+#endif // SUPPORT_METERED_DETECTION
+
+bool isNetworkConnected()
+{
+#if QT_VERSION >= QT_VERSION_CHECK(6, 3, 0)
+    const auto instance = QNetworkInformation::instance();
+    if (instance->supports(QNetworkInformation::Feature::Reachability) && instance->reachability() != QNetworkInformation::Reachability::Online) {
+        return false;
+    }
+#elif HAVE_NetworkManagerQt
+    if (NetworkManager::connectivity() != NetworkManager::Connectivity::Full) {
+        return false;
+    }
+#endif
+    return true;
+}
 }
 
 PotdClient::PotdClient(const KPluginMetaData &metadata, const QVariantList &args, QObject *parent)
@@ -50,7 +78,7 @@ void PotdClient::updateSource(bool refresh)
     setLoading(true);
 
     // Check whether it is cached already...
-#if HAVE_NetworkManagerQt
+#if SUPPORT_METERED_DETECTION
     // Use cache even if it's outdated when using metered connection
     const bool ignoreAge = m_doesUpdateOverMeteredConnection == 0 && isUsingMeteredConnection();
     if ((!refresh || ignoreAge /* Allow force refresh only when no cached image is available */) && CachedProvider::isCached(m_identifier, m_args, ignoreAge)) {
@@ -65,12 +93,8 @@ void PotdClient::updateSource(bool refresh)
         return;
     }
 
-    // Find the old cached image and load it for now
-    if (m_data.wallpaperImage.isNull()) {
-        const QString path = CachedProvider::identifierToPath(m_identifier, m_args);
-        if (QFile::exists(path)) {
-            setImage(QImage(path));
-        }
+    if (auto url = CachedProvider::identifierToPath(m_identifier, m_args); QFile::exists(url)) {
+        setLocalUrl(url);
     }
 
     const auto pluginResult = KPluginFactory::instantiatePlugin<PotdProvider>(m_metadata, this, m_args);
@@ -84,7 +108,7 @@ void PotdClient::updateSource(bool refresh)
     }
 }
 
-#if HAVE_NetworkManagerQt
+#if SUPPORT_METERED_DETECTION
 void PotdClient::setUpdateOverMeteredConnection(int value)
 {
     // Don't return if values are the same because there can be multiple
@@ -98,7 +122,6 @@ void PotdClient::setUpdateOverMeteredConnection(int value)
 
 void PotdClient::slotFinished(PotdProvider *provider)
 {
-    setImage(provider->image());
     setInfoUrl(provider->infoUrl());
     setRemoteUrl(provider->remoteUrl());
     setTitle(provider->title());
@@ -106,16 +129,22 @@ void PotdClient::slotFinished(PotdProvider *provider)
 
     // Store in cache if it's not the response of a CachedProvider
     if (qobject_cast<CachedProvider *>(provider) == nullptr) {
+        m_data.wallpaperImage = provider->image();
+        m_imageChanged = true;
         SaveImageThread *thread = new SaveImageThread(m_identifier, m_args, m_data);
         connect(thread, &SaveImageThread::done, this, &PotdClient::slotCachingFinished);
         QThreadPool::globalInstance()->start(thread);
     } else {
         // Is cache provider
         setLocalUrl(CachedProvider::identifierToPath(m_identifier, m_args));
+        if (m_imageChanged) {
+            m_imageChanged = false;
+            Q_EMIT imageChanged();
+        }
+        setLoading(false);
     }
 
     provider->deleteLater();
-    setLoading(false);
     Q_EMIT done(this, true);
 }
 
@@ -131,12 +160,8 @@ void PotdClient::slotError(PotdProvider *provider)
 void PotdClient::slotCachingFinished(const QString &, const PotdProviderData &data)
 {
     setLocalUrl(data.wallpaperLocalUrl);
-}
-
-void PotdClient::setImage(const QImage &image)
-{
-    m_data.wallpaperImage = image;
     Q_EMIT imageChanged();
+    setLoading(false);
 }
 
 void PotdClient::setLoading(bool status)
@@ -219,7 +244,15 @@ PotdEngine::PotdEngine(QObject *parent)
                                          this,
                                          SLOT(slotPrepareForSleep(bool)));
 
-#if HAVE_NetworkManagerQt
+#if QT_VERSION >= QT_VERSION_CHECK(6, 3, 0)
+    const auto instance = QNetworkInformation::instance();
+    if (instance->supports(QNetworkInformation::Feature::Metered)) {
+        connect(instance, &QNetworkInformation::isMeteredChanged, this, &PotdEngine::slotIsMeteredChanged);
+    }
+    if (instance->supports(QNetworkInformation::Feature::Reachability)) {
+        connect(instance, &QNetworkInformation::reachabilityChanged, this, &PotdEngine::slotReachabilityChanged);
+    }
+#elif HAVE_NetworkManagerQt
     connect(NetworkManager::notifier(), &NetworkManager::Notifier::connectivityChanged, this, &PotdEngine::slotConnectivityChanged);
 #endif
 }
@@ -280,6 +313,11 @@ void PotdEngine::unregisterClient(const QString &identifier, const QVariantList
 
 void PotdEngine::updateSource(bool refresh)
 {
+    if (!isNetworkConnected()) {
+        qCDebug(WALLPAPERPOTD) << "Network is not connected, so the backend will not update wallpapers.";
+        return;
+    }
+
     m_lastUpdateSuccess = true;
 
     for (const auto &[_, clientPair] : std::as_const(m_clientMap)) {
@@ -328,19 +366,29 @@ void PotdEngine::slotPrepareForSleep(bool sleep)
         return;
     }
 
-#if HAVE_NetworkManagerQt
-    if (NetworkManager::connectivity() != NetworkManager::Connectivity::Full) {
-        qCDebug(WALLPAPERPOTD) << "Waking up from sleep but the network is not connected yet.";
-        return;
-    }
-#endif
-
     // Resume from sleep
     // Always force update to work around the current date not being updated
     forceUpdateSource();
 }
 
-#if HAVE_NetworkManagerQt
+#if QT_VERSION >= QT_VERSION_CHECK(6, 3, 0)
+void PotdEngine::slotReachabilityChanged(QNetworkInformation::Reachability newReachability)
+{
+    if (newReachability == QNetworkInformation::Reachability::Online) {
+        qCDebug(WALLPAPERPOTD) << "Network is connected.";
+        updateSource(false);
+    }
+}
+
+void PotdEngine::slotIsMeteredChanged(bool isMetered)
+{
+    if (isMetered) {
+        return;
+    }
+
+    updateSource(false);
+}
+#elif HAVE_NetworkManagerQt
 void PotdEngine::slotConnectivityChanged(NetworkManager::Connectivity connectivity)
 {
     if (connectivity == NetworkManager::Connectivity::Full) {
